% Dibujamos todas las posibles distribuciones que mas se aproximan a la PDF
% de alarmas correctas

% Variables de entrada:
% x1: vector que contiene las distancias entre fingerprints
% x2: vector que contiene la cantidad de veces que se produce la misma
% distancia entre fingerprints
% m: tamaño de los fingerprints

% Fecha de creacion: 29 de Enero de 2006

function plot_distribuciones(x1,x2,m)

hold on; plot((1:229*32)/229/32,x2/sum(x2),'x')

hold on;

[a,b]=betafit(x1);
plot_dist_beta(a(1,1),a(1,2),m);

a=raylfit(x1);
plot_dist_rayleigh(a,m);

[a,b]=lognfit(x1);
plot_dist_lognormal(a(1,1),a(1,2),m);

[a,b]=wblfit(x1);
plot_dist_weibull(a(1,1),a(1,2),m);

xlabel('Tasa de error entre dos fingerprints');
ylabel('PDF');

hold off;